#!/bin/sh
#
#
#    Copyright (c) 1996-2004 Brocade Communications Systems, Inc.
#    All rights reserved.
#
#
# NAME
#      marathonpost1.sh - POST phase I support script for Marathon
# 
# AVAILABILITY
#      internal
# 
# DESCRIPTION
#      This  is  not  a  command.  It  is a script that manages the
#      POST(power on self test) phase I operations, which  involves
#      mainly in structual tests. The script is designed to operate
#      across power cycles.
# 
# SEE ALSO
#      marathonpost2(1d)
# 

#  Init variables
#
nPost=0			# number of POST executed
exit_status=0		# this script's exit status value
slot=0			# target slot to run POST
slot_message=""         # message related to slot information

#  special temp file used for each test result
#
logFile=/tmp/post1Log

#
#  function to process trapped signal received. Upon entry, KILL the
#  child PID and output the abort status
#
post_cleanup()
{
	if [ $?child ]
	then
	    /bin/kill $child
	fi
	#
	#  display ALL performed test result
	#
	_current_time=`/bin/date \+\%s`
	_date=`/bin/date`
	_duration=`/usr/bin/expr $_current_time - $startTime`
	_minute=`/usr/bin/expr $_duration / 60`
	_hour=`/usr/bin/expr $_minute / 60`
	_sec=`/usr/bin/expr $_duration % 60`
	_minute=`/usr/bin/expr $_minute % 60`
	/bin/echo "" >> $logFile.$slot
	/bin/echo "POST1:$slot_message POST1 script has been ABORTED $_date took ($_hour:$_minute:$_sec)"
	/bin/echo "POST1:$slot_message POST1 script has been ABORTED $_date took ($_hour:$_minute:$_sec)" >> $logFile.$slot
	/bin/echo "POST1:$slot_message Completed $nPost Diagnostic tests."
	/bin/echo "POST1:$slot_message Completed $nPost Diagnostic tests." >> $logFile.$slot
	exit 1
}


#
#  Function to wait for exec_diag return and process the return status.
#
checkStatus()
{
	#  wait for current child to finish and get return status
	#
	export child=$!
	wait $child
	rval=$?

	#  construct PASSED or FAILED msg from return value
	#  .  return value = 0 for PASSED
	#  .  return value != 0 for FAILED
	#
	case $rval in
	139 | 237 )
		echo " SKIPPED $1 due to Known Issue ($rval). Please run following command manually."
		echo "$*"
		echo " SKIPPED $1 due to Known Issue ($rval). Please run following command manually." >>  $logFile.$slot
		echo "$*" >>  $logFile.$slot
		;;
	0 )
		status=PASSED;;
	* )
		status=FAILED
		exit_status=`/usr/bin/expr $exit_status + 1`;;
	esac

	#  compute return status (positive or negative value)
	#
	if [ $rval -gt 127 ]
	then
		rval=`/usr/bin/expr $rval - 256`
	fi

	/bin/echo "POST1:$slot_message Returned status = $rval ($status)" >> $logFile.$slot
}

#
#  Function to get the hardware revision.
#
getHWversion()
{
chassisdata=`chassisshow -d575`
_data=`/bin/echo $chassisdata | /bin/sed "s/\// /g"`
_datacnt=`/bin/echo $_data | /usr/bin/wc -w`
i=1
rev=255

while [ $i -lt $_datacnt ]
do
   _data2=`/bin/echo $_data | /usr/bin/cut -d" " -f$i`
   if [ "$_data2" = "Slot:" ]
   then
        num=`/usr/bin/expr $i + 1`
        slotnum=`/bin/echo $_data | /usr/bin/cut -d" " -f$num`
        if [ "$slotnum" = "$1" ] 
   	then
   	   j=1
   	   while [ 1 ]
   	   do
   	      cnt1=`/usr/bin/expr $i + $j`
              if [ $cnt1 -gt $_datacnt ] 
   	      then
		 /bin/echo $rev
   	         return 1
   	      fi
   	         	      
   	      cnt2=`/usr/bin/expr $cnt1 + 1`
   	      cnt3=`/usr/bin/expr $cnt2 + 1`
   	      _data3=`/bin/echo $_data | /usr/bin/cut -d" " -f$cnt1`
   	      _data4=`/bin/echo $_data | /usr/bin/cut -d" " -f$cnt2`
              if { [ "$_data3" = "FRU" ]  && [ "$_data4" = "ID:" ]; }
   	      then
        	fru=`/bin/echo $_data | /usr/bin/cut -d" " -f$cnt3`
		rev=`/bin/echo $fru | /usr/bin/cut -c9-10` 
		/bin/echo $rev
        	return 0
   	      else
   	        if [ "$_data3" = "Manufacture:" ]
   	        then
		   /bin/echo $rev
   	           return 1
   	        fi
   	      fi   	     
   	      j=`/usr/bin/expr $j + 1`   	   
   	   done
   	   	
   	fi        
   fi
   i=`/usr/bin/expr $i + 1`
done
/bin/echo $rev
return 1
}

#  setup signal trap to call cleanup() if the followings:
#	control/d entered at the same window
#	kill <pid> is entered
#
trap "" 2
trap post_cleanup INT TERM KILL

#  export environment variable
#
DIAG_POST=1 ; export DIAG_POST
DIAG_USR_FAILLIM=1 ; export DIAG_USR_FAILLIM
setdbg DIAG 1

if [ $?FABOS_SLOTNO ]
then
	slot=$FABOS_SLOTNO
fi

#
# source diagcommon
#
home="/fabos/share"
util="diagcommon.sh"
ok=0
for f in "./$util" "$FABOSHOME/share/$util" "$home/$util" ; do
	if [ -r $f ] ; then
		. $f
		ok=1
		break;
	fi
done
if [ $ok -ne 1 ] ; then
	err "Could not locate $util"
	exit 3
fi

#
# get sys info for multi blade
#
multiBlade=`isMultiBlade`
if [ $multiBlade = TRUE ]
then
     slot_message="Slot $slot"
     export syntax="$0 -slot [slot] essScript"
else
     export syntax="$0 essScript"
fi

# cleanup the old log file
if [ -f $logFile.$slot ]
then
	/bin/rm $logFile.$slot
fi

#
#  display starting message
#
startTime=`/bin/date \+\%s`
_date=`/bin/date`
/bin/echo "POST1:$slot_message Started running $_date"
/bin/echo "POST1:$slot_message Started running $_date" >> $logFile.$slot

#
# Find exec_diag
#
cmd=`commandPath exec_diag`

#  reset Error on each port 
# 
/bin/echo "POST1:$slot_message Running diagclearerror" >> $logFile.$slot
$cmd diagclearerror $slot 2>&1 >> $logFile.$slot

#  perform Port Turboram test
#
nPost=`/usr/bin/expr $nPost + 1`
/bin/echo "" >> $logFile.$slot
revNum=`getHWversion $slot`
if { [ "$revNum" = "01" ] || [ "$revNum" = "02" ] ; }
then
  /bin/echo "POST1:$slot_message Test #$nPost - Skipping turboramtest" >> $logFile.$slot
  /bin/echo "POST1:$slot_message Test #$nPost - Skipping turboramtest"
else
  /bin/echo "POST1:$slot_message Test #$nPost - Running turboramtest" >> $logFile.$slot
  /bin/echo "POST1:$slot_message Test #$nPost - Running turboramtest"
  $cmd turboramtest 2>&1 >> $logFile.$slot &
  checkStatus turboramtest
fi

#  perform Port Register test
#
#nPost=`/usr/bin/expr $nPost + 1`
#/bin/echo "" >> $logFile.$slot
#/bin/echo "POST1:$slot_message Test #$nPost - Running portregtest" >> $logFile.$slot
#/bin/echo "POST1:$slot_message Test #$nPost - Running portregtest"
#$cmd portregtest 2>&1 >> $logFile.$slot &
#checkStatus portregtest

#  perform FCR chip test
#
nPost=`/usr/bin/expr $nPost + 1`
/bin/echo "" >> $logFile.$slot
/bin/echo "POST1:$slot_message Test #$nPost - Running fcrchiptest" >> $logFile.$slot
/bin/echo "POST1:$slot_message Test #$nPost - Running fcrchiptest"
$cmd fcrchiptest 2>&1 >> $logFile.$slot &
checkStatus fcrchiptest

#  check test status of each port (must be RUN in fore ground)
# 
/bin/echo "POST1:$slot_message Running diagshow"  >> $logFile.$slot
$cmd diagshow --slot $slot -use_bports 1 -silent 1 >> $logFile.$slot
status=$?

if [ $status -ne 0 ]
then
    exit_status=`/usr/bin/expr $exit_status + 1`
fi
#  display ALL performed test result
#
/bin/echo "" >> $logFile.$slot
/bin/echo "POST1:$slot_message  ********** $slot_message POST Summary  **********" >> $logFile.$slot
/bin/echo "POST1:$slot_message Completed $nPost Diagnostic test:" >> $logFile.$slot

#  display exit msg and exit script
#
if [ $exit_status -ne 0 ]
then
    status=FAILED
else
    status=PASSED
fi
_current_time=`/bin/date \+\%s`
_date=`/bin/date`
_duration=`/usr/bin/expr $_current_time - $startTime`
_minute=`/usr/bin/expr $_duration / 60`
_hour=`/usr/bin/expr $_minute / 60`
_sec=`/usr/bin/expr $_duration % 60`
_minute=`/usr/bin/expr $_minute % 60`
/bin/echo "POST1:$slot_message Script $status with exit status of $exit_status $_date took ($_hour:$_minute:$_sec)"
/bin/echo "POST1:$slot_message Script $status with exit status of $exit_status $_date took ($_hour:$_minute:$_sec)" >> $logFile.$slot
exit $exit_status
