# Set up hardware tables to use an IPSec AES/SHA security tunnel

# Set DT location and MII Linux Ethernet interface
script_path="/nfabos/bin/Hifn4350"
export DT="${script_path}/dt.ppc --i eth3 --pda ap --apdmawa on"
export DPU_DT="${script_path}/dt.ppc --i eth3 --apdmawa on"
export AP133=""

#Reset DPU/eSC via MII
echo write 0x80000E1C 0x00 0x00 0x01 0x00 | ${DT} ${AP133}

sleep 4

# SDRAM workaround over MII
${DT} --pda ap  --verify full --cdl ${script_path}/fw_ap_sdwa_1_1_1_1.cdl

# Load eSC POST firmware
${DT} --pda ap --verify full --cdl ${script_path}/esc_post_1_1_1_1.cdl

sleep 4

${DPU_DT} --verify full --cdl ${script_path}/DPU_43x0_sdram_1_1_1_4.cdl

sleep 4

echo ""

 
#echo "Put net0 in GMAC loopback"
#echo writetable 9 0 0x00f0781c | ${DPU_DT} 
echo "Config net0 GMAC"
echo writetable 9 0 0x00f0681c | ${DPU_DT}

#echo "Put net1 in GMAC loopback" 
#echo writetable 11 0 0x00f0781c | ${DPU_DT} 
echo "Config net1 GMAC"
echo writetable 11 0 0x00f0681c | ${DPU_DT}
echo ""

echo "Enable net0 promiscuous mode"
echo write 0x80000004 0x00 0x00 0x00 0x01 | ${DPU_DT}
echo ""

echo "Enable net1 promiscuous mode"
echo write 0x80001004 0x00 0x00 0x00 0x01 | ${DPU_DT}

echo ""
echo "Enable host1 send and receive"
echo write 0x80003000 0x00 0xf0 0x68 0x1c | ${DPU_DT}
echo ""

# To enable a security Policy:
# Outbound Tables:
#	SPD - Security Policy Database
#	SAM - Security Association Mask
#	SAL - SA Lookup 
#	SAD - Security Association Database
#
# Inbound Tables:
#	SAL - SA Lookup
#	SAD - Security Association Database
#
# First set the outbound SPD table 
# In this example all the values for both tables are the same
#
# Outbound policy entry
#  Similar to sm-api: 
#  setpolicy -priority 0 -kind esp -action ipsec -en aes128 -an sha1 \
#            -sav 0.0.0.10 -dav 0.0.0.12 \
#            -spi 0x30123 -tunnel YES -tunsav 0.8.0.10 -tundav 0.8.0.12 


policy_source_address_match=0x0000000a
policy_dest_address_match=0x0000000c
policy_source_port_match=0x0000
policy_dest_port_match=0x0000
policy_protocol_match_h=0x00
policy_reserved=0
policy_source_address_mask=0xffffffff
policy_dest_address_mask=0xffffffff
policy_action=4
policy_phy_port_match=0
policy_vlan_match=0x000
policy_reserved_zero=0
policy_phy_port_mask=0
policy_vlan_mask=0x000
policy_protocol_match_l=0x0
policy_src_port_mask_bit=0
policy_dst_port_mask_bit=0
policy_protocol_mask_bit=0
policy_valid_bit=1
policy_reserved_2=0

# command + table index + SPD slot + data
echo "Write Outbound SPD table entry 0"
echo writetable 15 0 $policy_source_address_match $policy_dest_address_match $policy_source_port_match $policy_dest_port_match $policy_protocol_match_h $policy_reserved $policy_source_address_mask $policy_dest_address_mask $policy_action $policy_phy_port_match $policy_vlan_match $policy_reserved_zero $policy_phy_port_mask $policy_vlan_mask $policy_protocol_match_l $policy_src_port_mask_bit $policy_dst_port_mask_bit $policy_protocol_mask_bit $policy_valid_bit $policy_reserved_2| ${DPU_DT}

dest_addr=0xffffffff
src_addr=0xffffffff
src_port=0x0000
dest_port=0x0000
misc_sel=0
phy_port=0
vlan_id=0x000
reserved=0
invalid=0
reserved=0
protocol=0x00

# command + table index + SAM slot + data
echo "Write Outbound SAM table entry 0"
echo writetable 17 0 $dest_addr $src_addr $src_port $dest_port $misc_sel $phy_port $vlan_id $reserved $invalid $reserved $protocol | ${DPU_DT}

#
# OB SALU

dest_addr=0x0000000c
src_addr=0x0000000a
src_port=0x0000
dest_port=0x0000
misc_sel=0
phy_port=0
vlan_id=0x000
invalid=0
must_be_0=0
sadindx_h=0
nxt_link_h=0
protocol=0x00
sadindx_l=0x0001
nxt_link_l=0

# command + table index + SAL slot + data
echo "Write Outbound SAL table entry 1"
echo tableop 0 0 $dest_addr $src_addr $src_port $dest_port $misc_sel $phy_port $vlan_id $invalid $must_be_0 $sadindx_h $nxt_link_h $protocol $sadindx_l $nxt_link_l | ${DPU_DT}


# OB SAD
mtu=0x00002474
extended_flag=0x00000000
salifetime_softtime=0x0fffffff
salifetime_softbyte_l=0xffffffff
tunnel_ctrl=0x00000000
sabytecnt_l=0
sauserbytecnt_l=0
sapktcnt_l=0
seqnum_l=1
flags_h=0x009b0008
flags_l=0x00000000
srcIP=0x0008000a
destIP=0x0008000c
spi=0x00030123
hmac_ipad_key_a=0x04030201
hmac_ipad_key_b=0x08070605
hmac_ipad_key_c=0x12111009
hmac_ipad_key_d=0x16151413
hmac_ipad_key_e=0x12345612
hmac_opad_key_a=0x20191817
hmac_opad_key_b=0x23222120
hmac_opad_key_c=0x27262524
hmac_opad_key_d=0x31302928
hmac_opad_key_e=0x127890ab
aes_3des_key_0=0x01020408
aes_3des_key_1=0x10204080
aes_3des_key_2=0x02040801
aes_3des_key_3=0x20408010
aes_3des_key_4=0x04080102
aes_3des_key_5=0x40801020
aes_3des_key_6=0x08010204
aes_3des_key_7=0x80102040
seqnum_h=0
aesctr256_nonce=0x00000000
salifetime_hardtime=0x0fffffff
salifetime_hardbyte_h=0x0fffffff
salifetime_hardbyte_l=0xffffffff
salifetime_softbyte_h=0xffffffff
sabytecnt_h=0
sapktcnt_h=0
sauserbytecnt_h=0

# command + table index + SAL slot + data
echo "Write Outbound SAD table entry 1"
echo writetable 2 1 $mtu $extended_flag $salifetime_softtime $salifetime_softbyte_l $tunnel_ctrl $sabytecnt_l $sauserbytecnt_l $sapktcnt_l $seqnum_l $flags_h $flags_l $srcIP $destIP $spi $hmac_ipad_key_a $hmac_ipad_key_b $hmac_ipad_key_c $hmac_ipad_key_d $hmac_ipad_key_e $hmac_opad_key_a $hmac_opad_key_b $hmac_opad_key_c $hmac_opad_key_d $hmac_opad_key_e $aes_3des_key_0 $aes_3des_key_1 $aes_3des_key_2 $aes_3des_key_3 $aes_3des_key_4 $aes_3des_key_5 $aes_3des_key_6 $aes_3des_key_7 $seqnum_h $aesctr256_nonce $salifetime_hardtime $salifetime_hardbyte_h $salifetime_hardbyte_l $salifetime_softbyte_h $sabytecnt_h $sapktcnt_h $sauserbytecnt_h | ${DPU_DT}


# Inbound policy entry not required - SA Selector Checks used instead
#

# Inbound SALU
spi=0x00030123
dest_addr=0x0008000c
invalid=0
misc_sel=0
phy_port=0
vlan_id=0x000
sal_mask=3
sadindx_h=0
nxt_link_h=0
protocol=0x32
sadindx_l=0x0001
nxt_link_l=0

# command + table index + SAL slot + data
echo "Write Inbound SAL table entry 1"
echo tableop 1 0 $spi $dest_addr $invalid $misc_sel $phy_port $vlan_id $sal_mask $sadindx_h $nxt_link_h $protocol $sadindx_l $nxt_link_l | ${DPU_DT}


#
# Inbound SAD
reserved=0
extended_flag=0x00000000
salifetime_softtime=0xffffffff
sabytecnt_l=0
sapktcnt_l=0
salifetime_softbyte_l=0xffffffff
sabytecnt_h=0
salifetime_softbyte_h=0xffffffff
salifetime_hardbyte_l=0xffffffff
flags_h=0x049b2008
flags_l=0x00000000
seqnum_h=0
hmac_ipad_key_a=0x04030201
hmac_ipad_key_b=0x08070605
hmac_ipad_key_c=0x12111009
hmac_ipad_key_d=0x16151413
hmac_ipad_key_e=0x12345612
hmac_opad_key_a=0x20191817
hmac_opad_key_b=0x23222120
hmac_opad_key_c=0x27262524
hmac_opad_key_d=0x31302928
hmac_opad_key_e=0x127890ab
aes_3des_key_0=0x01020408
aes_3des_key_1=0x10204080
aes_3des_key_2=0x02040801
aes_3des_key_3=0x20408010
aes_3des_key_4=0x04080102
aes_3des_key_5=0x40801020
aes_3des_key_6=0x08010204
aes_3des_key_7=0x80102040
source_address_match=0x0000000a
dest_address_match=0x0000000c
source_port_match=0x0000
dest_port_match=0x0000
misc_match=0
phy_port_match=0
vlan_match=0x000
reserved_match=0
#protocol_match=0x11
protocol_match=0
source_address_mask=0xffffffff
dest_address_mask=0xffffffff
misc_mask=0
phy_port_mask=0
vlan_mask=0x000
reserved_mask=0
source_port_mask=0
dest_port_mask=0
#protocol_mask=1
protocol_mask=0
sa_user_byte_count_h=0
sa_user_byte_count_l=0
anti_replay_hsn=0
anti_replay_window_hh=0
anti_replay_window_hl=0
anti_replay_window_lh=0
anti_replay_window_ll=0
replay_error_count=0
aes_ctr_256_nonce=0x00000000
salifetime_hardtime=0xffffffff
salifetime_hardbyte_h=0xffffffff
sa_packet_count_h=0
auth_error_count=0
pad_error_count=0
reserved_3=0
reserved_4=0
 
# command + table index + SAL slot + data
echo "Write Inbound SAD table entry 1"
echo writetable 3 1 $reserved $extended_flag $salifetime_softtime $sabytecnt_l $sapktcnt_l $salifetime_softbyte_l $sabytecnt_h $salifetime_softbyte_h $salifetime_hardbyte_l $flags_h $flags_l $seqnum_h $hmac_ipad_key_a $hmac_ipad_key_b $hmac_ipad_key_c $hmac_ipad_key_d $hmac_ipad_key_e $hmac_opad_key_a $hmac_opad_key_b $hmac_opad_key_c $hmac_opad_key_d $hmac_opad_key_e $aes_3des_key_0 $aes_3des_key_1  $aes_3des_key_2 $aes_3des_key_3 $aes_3des_key_4 $aes_3des_key_5 $aes_3des_key_6 $aes_3des_key_7 $source_address_match $dest_address_match $source_port_match $dest_port_match $misc_match $phy_port_match $vlan_match $reserved_match $protocol_match $source_address_mask $dest_address_mask $misc_mask $phy_port_mask $vlan_mask $reserved_mask  $source_port_mask  $dest_port_mask $protocol_mask  $sa_user_byte_count_h $sa_user_byte_count_l $anti_replay_hsn $anti_replay_window_hh $anti_replay_window_hl $anti_replay_window_lh $anti_replay_window_ll $replay_error_count $aes_ctr_256_nonce $salifetime_hardtime $salifetime_hardbyte_h $sa_packet_count_h  $auth_error_count $pad_error_count $reserved_3 $reserved_4 | ${DPU_DT} 

echo ""
echo "If no errors are reported, N0 and N1 are now in SPD policy bypass mode"
