#!/bin/sh
db_module_path="/fabos/modules"
dmodule_path="/nfabos/modules"
script_path="/nfabos/bin/Hifn4350"

##################################
# NAME
#    getSWBD - Output the software board ID
#
# SYNOPSIS
#    getSWBD
#
# DESCRIPTION
#    This function parses the output of the sin command to extract the
#    SWBD value for this platform.
#
#    Use of this function is discouraged. We intend to move the scripts
#    toward a capability of property driven queries instead of parsing
#    model numbers to reduce future maintainence.
#
# OPERANDS
#    NONE
##################################
getSWBD()
{
	_abc=`/sbin/sin | \
		  /bin/grep Platform | \
		  /usr/bin/cut -d" " -f2 | \
		  /usr/bin/cut -d"," -f1`
	/bin/echo $_abc
}

product=`getSWBD`


case "$1" in
'start')

	# invoke the proper diag pci module
	case "$product" in
		"SWBD21" | "SWBD42" )
		echo "SWBD21 SWBD42"
		echo "Installing db module"
		/sbin/insmod -f ${db_module_path}/db-module.o || exit 1

		echo "Installing dpci chassis module"
		/sbin/insmod -f ${dmodule_path}/dpci_chassis.o || exit 1
		major=`cat /proc/devices | /bin/grep dpci | cut -f 1 -d" "`
		rm -f /dev/dpci_chassis
		mknod /dev/dpci_chassis c $major 0
        echo "Installing dpregtest module"
        /sbin/insmod -f ${dmodule_path}/dpregtest.o || exit 1
        major=`cat /proc/devices | /bin/grep dpregtest | cut -f 1 -d" "`
        rm -f /dev/dpregtest
        mknod /dev/dpregtest c $major 0

        echo "Installing dgen module"
        /sbin/insmod -f ${dmodule_path}/dgen.o || exit 1
        major=`cat /proc/devices | /bin/grep dgen | cut -f 1 -d" "`
        rm -f /dev/dgen
        mknod /dev/dgen c $major 0
	;;
	"SWBD32" | "SWBD37" | "SWBD44" )
		echo "SWBD32 SWBD37 SWBD44"
		echo "Installing dpci switch module"
		/sbin/insmod -f ${dmodule_path}/dpci_switch.o || exit 1
		major=`cat /proc/devices | /bin/grep dpci | cut -f 1 -d" "`
		rm -f /dev/dpci_switch
		mknod /dev/dpci_switch c $major 0

        rm -f /dev/gpio
        # mknod for /dev/gpio for cpld asscess
        mknod /dev/gpio c 10 185
        echo "Installing dpregtest module"
        /sbin/insmod -f ${dmodule_path}/dpregtest.o || exit 1
        major=`cat /proc/devices | /bin/grep dpregtest | cut -f 1 -d" "`
        rm -f /dev/dpregtest
        mknod /dev/dpregtest c $major 0

        echo "Installing dgen module"
        /sbin/insmod -f ${dmodule_path}/dgen.o || exit 1
        major=`cat /proc/devices | /bin/grep dgen | cut -f 1 -d" "`
        rm -f /dev/dgen
        mknod /dev/dgen c $major 0
	;;
	"SWBD36" )
		# enable telnet as per fabos
		echo "SWBD36"
		echo '#!/bin/sh' > /fabos/etc/swInst
		echo 'echo sw0' >> /fabos/etc/swInst
		chmod +x /fabos/etc/swInst
		echo '#!/bin/sh' > /fabos/bin/secModeGet
		echo 'echo 0' >> /fabos/bin/secModeGet
		chmod +x /fabos/bin/secModeGet

		echo "Installing dpci switch module"
		/sbin/insmod -f ${dmodule_path}/dpci_switch.o || exit 1
		major=`cat /proc/devices | /bin/grep dpci | cut -f 1 -d" "`
		rm -f /dev/dpci_switch
		mknod /dev/dpci_switch c $major 0
		rm -f /dev/gpio
        # mknod for /dev/gpio for cpld asscess
        mknod /dev/gpio c 10 185
        echo "Installing dpregtest module"
        /sbin/insmod -f ${dmodule_path}/dpregtest.o || exit 1
        major=`cat /proc/devices | /bin/grep dpregtest | cut -f 1 -d" "`
        rm -f /dev/dpregtest
        mknod /dev/dpregtest c $major 0

        echo "Installing dgen module"
        /sbin/insmod -f ${dmodule_path}/dgen.o || exit 1
        major=`cat /proc/devices | /bin/grep dgen | cut -f 1 -d" "`
        rm -f /dev/dgen
        mknod /dev/dgen c $major 0
#		${script_path}/hifn_4350_dl.sh
		${script_path}/4350_post.sh

		result=`echo $?`
		# if 4350 post fails, don't run nfdiag for BladeStandlaone
		if [ $result -eq 0 ]
		then
			echo "4350 post PASSED."
			# If BladeStandalone flag is not set, run nfdiag automatically
			BladeStandAlone=`bootenv -v BladeStandalone 2> /dev/null`
			if [ "$BladeStandAlone" != "BladeStandalone=yes" ]
			then
				/nfabos/bin/nfdiag
			fi
		else
			echo "4350 post FAILED."
		fi

	;;
	"SWBD46" )
		echo "SWBD46"
		echo "Installing dpci switch module"
		/sbin/insmod -f ${dmodule_path}/dpci_switch.o || exit 1
		major=`cat /proc/devices | /bin/grep dpci | cut -f 1 -d" "`
		rm -f /dev/dpci_switch
		mknod /dev/dpci_switch c $major 0
		rm -f /dev/gpio
        # mknod for /dev/gpio for cpld asscess
        mknod /dev/gpio c 10 185
        echo "Installing dpregtest module"
        /sbin/insmod -f ${dmodule_path}/dpregtest.o || exit 1
        major=`cat /proc/devices | /bin/grep dpregtest | cut -f 1 -d" "`
        rm -f /dev/dpregtest
        mknod /dev/dpregtest c $major 0

        echo "Installing dgen module"
        /sbin/insmod -f ${dmodule_path}/dgen.o || exit 1
        major=`cat /proc/devices | /bin/grep dgen | cut -f 1 -d" "`
        rm -f /dev/dgen
        mknod /dev/dgen c $major 0
		# ${script_path}/hifn_4350_dl.sh
		# /nfabos/bin/nfdiag
	;;
	*)
		echo "ERROR: unsupported platform: $product"
		return 1
	;;
	esac

;;
'stop')
    # remove the proper diag pci module
    case "$product" in
        "SWBD21" | "SWBD42" )
        /sbin/rmmod dpci_chassis || exit 1
        rm -f /dev/dpci_chassis

        /sbin/rmmod db-module || exit 1
    ;;
    "SWBD32" )
        /sbin/rmmod dpci_switch || exit 1
        rm -f /dev/dpci_switch
		rm -f /dev/gpio
    ;;
	"SWBD36" | "SWBD37" | "SWBD46" | "SWBD44" )
        /sbin/rmmod dpci_switch || exit 1
        rm -f /dev/dpci_switch
	;;
    *)
        echo "ERROR: unsupported platform: $product"
        return 1
    ;;
    esac

	/sbin/rmmod dpregtest || exit 1
	rm -f /dev/dpregtest

	/sbin/rmmod dgen || exit 1
	rm -f /dev/dgen

;;	
*)
    echo "usage: $0 {start | stop}"
;;
esac
